"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * <p>The GridColumn Component works inside of the '<b>Grid.js</b>' Component and this is used for the layout of the grid columns. See <a href="http://internal-uifw/docs/grid.html" target="_blank">Grids</a> for more information.</p>
 */
var GridColumn = function GridColumn(props) {
  var ibType = props.ibtype ? "uifw-gc-ib-".concat(props.ibtype) : '';
  var offset = props.offsetsize ? "uifw-gc-os-".concat(props.offsetsize) : '';
  var mobileColsize = props.mobileColsize ? "uifw-gc-xs-".concat(props.mobileColsize) : '';
  return _react["default"].createElement("div", {
    ref: props.refCallback,
    id: props.id,
    className: (0, _classnames["default"])("uifw-gc-".concat(props.colsize), mobileColsize, offset, ibType, props.additionalClasses)
  }, props.children);
};

GridColumn.propTypes = {
  /**
  * The id is used for giving the DOM ELement a unique identifier.
  */
  id: _propTypes["default"].string,

  /**
   * the callback for getting the ref for the container div
   <<example>>refCallback={(ref) => this.gridColumn = ref; }
   */
  refCallback: _propTypes["default"].func,

  /**
   * The width of the column, it is split into 12 sections so if this has a value of 6 it will be half the width of the grid itself
   <<example>>colsize="6"
   */
  colsize: _propTypes["default"].string.isRequired,

  /**
   * The width of the column on mobile, it is split into 12 sections so if this has a value of 6 it will be half the width of the grid itself
   <<example>>colsize="6"
   */
  mobileColsize: _propTypes["default"].string,

  /**
   * The additional classes that are given to the grid column wrapper div
   <<example>>additionalclasses="string"
   */
  additionalClasses: _propTypes["default"].string,

  /**
   * The offset of the column, if the value is 6 it will add empty space to the first half of the grid
   <<example>>offsetsize="6"
   */
  offsetsize: _propTypes["default"].string,

  /**
   * The inline block type of the column
   <<example>>ibtype="string"
   */
  ibtype: _propTypes["default"].string,

  /**
   * The content of the column for the specified row
   <<example>><uifw.GridColumn>
   *  <ColumnContent>...</ColumnContent>
   *</uifw.GridColumn>
   */
  children: _propTypes["default"].node
};
GridColumn.defaultProps = {
  id: null,
  refCallback: null,
  mobileColsize: null,
  additionalClasses: null,
  offsetsize: null,
  ibtype: null,
  children: null
};
var _default = GridColumn;
exports["default"] = _default;