"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * <p>The GridRow components will wrap a list of '<b>GirdColumn.js</b>' components and should be included inside the '<b>Grid.js</b>' component.
 * See <a href="http://internal-uifw/docs/grid.html" target="_blank">Grids</a> for more information.</p>
 */
var GridRow = function GridRow(props) {
  return _react["default"].createElement("div", {
    ref: props.refCallback,
    id: props.id ? props.id : null,
    className: (0, _classnames["default"])({
      'uifw-gr-p0': props.noSpacing,
      'uifw-gr': !props.noSpacing
    }, props.additionalClasses)
  }, props.children);
};

GridRow.propTypes = {
  /**
  * The id is used for giving the DOM ELement a unique identifier.
  */
  id: _propTypes["default"].string,

  /**
   * the callback for getting the ref for the container div
   <<example>>refCallback={(ref) => this.gridRow = ref; }
   */
  refCallback: _propTypes["default"].func,

  /**
   * Sets whether or not the row has spacing or not
   <<example>>noSpacing={true}
   */
  noSpacing: _propTypes["default"].bool,

  /**
   * The children to be rendered within each row (this is nearly always a list of
   * '<b>Grid.js</b>' Components)
   <<example>><uifw.GridRow>
   * <uifw.GridColumn>...</uifw.GridColumn>
   * <uifw.GridColumn>...</uifw.GridColumn>
   * <uifw.GridColumn>...</uifw.GridColumn>
   *</uifw.GridRow>
   */
  children: _propTypes["default"].node,

  /**
  * This is used to apply extra classes to the DOM Element.
  *<<example>> additionalClasses="extraCssClass"
  */
  additionalClasses: _propTypes["default"].string
};
GridRow.defaultProps = {
  id: null,
  refCallback: null,
  noSpacing: false,
  children: null,
  additionalClasses: null
};
var _default = GridRow;
exports["default"] = _default;