"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * <p>The Grid Component is the wrapper div for the uifw grid layout and should have the '<b>GridColumn.js</b>'
 * and the '<b>GridRow.js</b>' Components as children in order for the grid layout to work. See <a href="http://internal-uifw/docs/grid.html" target="_blank">Grids</a> for more information.</p>
 */
var Grid = function Grid(props) {
  return _react["default"].createElement("div", {
    ref: props.refCallback,
    id: props.id ? props.id : null,
    className: (0, _classnames["default"])({
      'uifw-grid': !props.ib,
      'uifw-grid-ib': props.ib
    }, props.additionalClasses)
  }, props.children);
};

Grid.propTypes = {
  /**
  * The id is used for giving the DOM ELement a unique identifier.
  */
  id: _propTypes["default"].string,

  /**
   * Sets whether or not the grid has an inline block
   <<example>>ib={false}
   */
  ib: _propTypes["default"].bool,

  /**
   * the callback for getting the ref for the container div
   <<example>>refCallback={(ref) => this.grid = ref; }
   */
  refCallback: _propTypes["default"].func,

  /**
   * The additional CSS class names that the grid wrapper div will have
   <<example>>additionalClasses="string"
   */
  additionalClasses: _propTypes["default"].string,

  /**
   * The content of the grid, this will be a collection of GridColumn and GridRow components
   <<example>><uifw.Grid>
   *   <uifw.GridRow>
   *    <uifw.GridColumn>...</uifw.GridColumn>
   *    <uifw.GridColumn>...</uifw.GridColumn>
   *    <uifw.GridColumn>...</uifw.GridColumn>
   *   </uifw.GridRow>
   *</uifw.Grid>
   */
  children: _propTypes["default"].node
};
Grid.defaultProps = {
  id: null,
  ib: false,
  refCallback: null,
  additionalClasses: null,
  children: null
};
var _default = Grid;
exports["default"] = _default;