"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * <p>The inline message Component is used to display information for a form row within the form row itself. See <a href="http://internal-uifw/elements.html#message-inline-message" target="_blank">Inline Message</a> for more information.</p>
 */
var InlineMessageWithChildren = function InlineMessageWithChildren(props) {
  var icon = props.icon == null ? 'uifw-icon-exclamation-triangle' : props.icon;
  return _react["default"].createElement("div", {
    id: props.id,
    className: (0, _classnames["default"])('uifw-form-row-section', {
      'u-anim-fadeout': props.visible !== true,
      'u-anim-fadein': props.visible === true
    }, props.additionalClasses),
    style: props.style
  }, _react["default"].createElement("div", {
    className: "uifw-inline-message ".concat(props.type)
  }, _react["default"].createElement("i", {
    className: "uifw-icon ".concat(icon)
  }), _react["default"].createElement("div", {
    className: "uifw-inline-message-body"
  }, props.children)));
};

InlineMessageWithChildren.propTypes = {
  /**
  * The children of the inline message to be displayed
   <<example>><p>message</p>
  */
  children: _propTypes["default"].node,

  /**
  * The type of inline message to be displayed
   <<example>>type="warning"
   *type="error"
   *type="done"
   *type="information"
  */
  type: _propTypes["default"].string.isRequired,

  /**
  * The visibility of the inline message
   <<example>>visible={true}
  */
  visible: _propTypes["default"].bool,

  /**
  * Additonal CSS for the wrapping div
   <<example>>additionalClasses="string"
  */
  additionalClasses: _propTypes["default"].string,

  /**
  * The id that is given to the wrapping div
   <<example>>id="string"
  */
  id: _propTypes["default"].string,

  /**
  * The icon that is displayed before the inline message
   <<example>>icon="uifw-icon-standard-check" // default value {"uifw-icon-exclamation-triangle"}
  */
  icon: _propTypes["default"].string,

  /**
  * The inline style object that is passed to the wrapper div
   <<example>>style={
     {
      marginTop: "10px",
      color: "#000"
    }
   }
  */
  style: _propTypes["default"].object
};
InlineMessageWithChildren.defaultProps = {
  children: null,
  visible: true,
  additionalClasses: null,
  id: null,
  icon: null,
  style: null
};
var _default = InlineMessageWithChildren;
exports["default"] = _default;