"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * <p>The TableCell Component is used with the '<b>Table.js</b>' and the '<b>TableRow.js</b>' to create a uifw div markup table. This is where the content of the table cell will go.
 * See <a href="http://internal-uifw/elements.html#tables-data-table-divs" target="_blank">Table</a> for more information.<p>
 */
var TableCell = function TableCell(props) {
  return _react["default"].createElement("div", {
    className: (0, _classnames["default"])({
      'uifw-table-header-column': props.isHeader,
      'uifw-table-column': !props.isHeader
    }, props.additionalCss)
  }, props.children);
};

TableCell.propTypes = {
  /**
   * Defines if the cell should have a header class applied to it. This is usually passed down through the Table Row Component but can be set manually like so
   <<example>>isHeader={false}
   */
  isHeader: _propTypes["default"].bool,

  /**
   * The additional CSS classes that are passed to the wrapping cell div
   <<example>>additionalCss="string"
   */
  additionalCss: _propTypes["default"].string,

  /**
   * The content of the table cell
   <<example>><uifw.TableCell>
   *  <TableCellContent>...</TableCellContent>
   *</uifw.TableCell>
   */
  children: _propTypes["default"].node
};
TableCell.defaultProps = {
  isHeader: false,
  additionalCss: null,
  children: null
};
var _default = TableCell;
exports["default"] = _default;