"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * <p>The TableRow Component is used with the '<b>Table.js</b>' and the '<b>TableCell.js</b>' to create a uifw div markup table. This defines a row for the table and should contain TableCells.
 * See <a href="http://internal-uifw/elements.html#tables-data-table-divs" target="_blank">Table</a> for more information.<p>
 */
var TableRow = function TableRow(props) {
  var children = props.children;

  if (props.isHeader === true) {
    children = _react["default"].Children.map(children, function (child) {
      return _react["default"].cloneElement(child, {
        isHeader: true
      });
    });
  }

  return _react["default"].createElement("div", {
    className: (0, _classnames["default"])({
      'uifw-table-header-row': props.isHeader,
      'uifw-table-row': !props.isHeader
    }, props.additionalCss)
  }, children);
};

TableRow.propTypes = {
  /**
   * Defines if the row is  a header row or not
  *	 <<example>>isHeader={false}
   */
  isHeader: _propTypes["default"].bool,

  /**
     * The additional CSS classes that are passed to the table row
    <<example>>additionalCss={false}
     */
  additionalCss: _propTypes["default"].string,

  /**
   * The content of the row, this usually consists of TableCell's
   <<example>><uifw.TableRow>
   *  <uifw.TableCell>...</uifw.TableCell>
   *  <uifw.TableCell>...</uifw.TableCell>
   *  <uifw.TableCell>...</uifw.TableCell>
   *</uifw.TableRow>
   */
  children: _propTypes["default"].node
};
TableRow.defaultProps = {
  isHeader: false,
  additionalCss: null,
  children: null
};
var _default = TableRow;
exports["default"] = _default;