"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var $ = require('jquery');

var Validation = {
  validateText: function validateText(value, validationArray) {
    if (validationArray) {
      for (var i = 0; i <= validationArray.length - 1; i++) {
        var validation = validationArray[i];

        if (_typeof(validation) === 'object') {
          if (typeof validation.action === 'string') {
            var check = presetValidation(value, validation.action, validation.errorMsg, validation.array);
            if (!check.valid) return check;
          } else if (typeof validation.action === 'function') {
            var check = customFunction(value, validation.action, validation.errorMsg);
            if (!check.valid) return check;
          } else if (validation.action instanceof RegExp) {
            var check = regexValidation(value, validation.action, validation.errorMsg);
            if (!check.valid) return check;
          } else {
            return {
              valid: false,
              errorMsg: "Validation action must be a string for a preset method, function for custom validation function or a regular expression."
            };
          }
        } else {
          return {
            valid: false,
            errorMsg: "Validation supplied not of type object. Example validation object: { action: \"required\", errorMsg: \"Custom error message.\" }"
          };
        }
      }
    } else {
      return {
        valid: false,
        errorMsg: "Validation action not defined. Please choose from a preset validation method name, supply your own validation function or supply a regular expression."
      };
    }

    return {
      valid: true
    };
  },
  checkIfOnScreen: function checkIfOnScreen(elements) {
    var element = elements.getBoundingClientRect();

    if (element.top >= 0 && element.left >= 0 && element.right <= (window.innerWidth || document.documentElement.clientWidth) && element.bottom <= (window.innerHeight || document.documentElement.clientHeight)) {
      return true;
    }

    return false;
  },
  scrollIntoViewCustomFun: function scrollIntoViewCustomFun(input) {
    var offset = $(input).offset();
    offset.left -= 100;
    offset.top -= 100;
    $('html, body').animate({
      scrollTop: offset.top,
      scrollLeft: offset.left
    });
    return true;
  },
  validateForm: function validateForm(formNode) {
    var valid = true;
    var isScrolled = false;
    var onScreen = false;
    var errors = [];
    $(formNode.getElementsByTagName('input')).each(function (i, input) {
      if ($(this).data('validation')) {
        var validationMethods = $(this).data('validation');
        var result = Validation.validateText(this.value, validationMethods);
        this.setAttribute('data-formvalidationmessage', result.errorMsg == null ? "" : result.errorMsg);

        if (!result.valid) {
          errors.push(result);

          if (Validation.checkIfOnScreen(input)) {
            onScreen = true;
          }

          if (isScrolled === false && onScreen === false) {
            isScrolled = Validation.scrollIntoViewCustomFun(input);
          }

          $(this).trigger("updateValidationAttribute", [result.errorMsg]);
        }
      }
    });
    $(formNode.getElementsByTagName('select')).each(function (i, input) {
      if ($(this).data('validation')) {
        var validationMethods = $(this).data('validation');
        var result = Validation.validateText(this.value, validationMethods);
        this.setAttribute('data-formvalidationmessage', result.errorMsg == null ? "" : result.errorMsg);

        if (!result.valid) {
          errors.push(result);

          if (Validation.checkIfOnScreen(input)) {
            onScreen = true;
          }

          if (isScrolled === false && onScreen === false) {
            isScrolled = Validation.scrollIntoViewCustomFun(input);
          }

          $(this).trigger("updateValidationAttribute", [result.errorMsg]);
        }
      }
    });
    $(formNode.getElementsByTagName('textarea')).each(function (i, input) {
      if ($(this).data('validation')) {
        var validationMethods = $(this).data('validation');
        var result = Validation.validateText(this.value, validationMethods);
        this.setAttribute('data-formvalidationmessage', result.errorMsg == null ? "" : result.errorMsg);

        if (!result.valid) {
          errors.push(result);

          if (Validation.checkIfOnScreen(input)) {
            onScreen = true;
          }

          if (isScrolled === false && onScreen === false) {
            isScrolled = Validation.scrollIntoViewCustomFun(input);
          }

          $(this).trigger("updateValidationAttribute", [result.errorMsg]);
        }
      }
    });
    $('.uifw-validated-element', formNode).each(function (i, input) {
      if ($(this).data('validation')) {
        var validationMethods = $(this).data('validation');
        var result = Validation.validateText('', validationMethods);
        this.setAttribute('data-formvalidationmessage', result.errorMsg == null ? "" : result.errorMsg);

        if (!result.valid) {
          errors.push(result);

          if (Validation.checkIfOnScreen(input)) {
            onScreen = true;
          }

          if (isScrolled === false && onScreen === false) {
            isScrolled = Validation.scrollIntoViewCustomFun(input);
          }

          $(this).trigger("updateValidationAttribute", [result.errorMsg]);
        }
      }
    });

    if (errors.length > 0) {
      valid = false;
    }

    if (window.CustomEvent) {
      var event = new CustomEvent("formValidationComplete", {
        detail: {
          formNode: formNode,
          valid: valid,
          time: new Date()
        },
        bubbles: true,
        cancelable: true
      });
      window.dispatchEvent(event);
    }

    return valid;
  }
};

var presetValidation = function presetValidation(value, validationName, errorMsg, array) {
  var emailRegex = /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/;

  switch (validationName) {
    case 'required':
      if (value === null || value === undefined || value.toString().trim() === '') {
        return {
          valid: false,
          errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value is required.'
        };
      }

      break;

    case 'text':
      var regex = /^[a-zA-Z ]*$/;
      var isValid = regex.test(value);
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must be a string.'
      };
      break;

    case 'number':
      var regex = /^(\s*|\d+)$/;
      var isValid = regex.test(value.trim()) === true && value.trim() !== "" ? true : false;
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must be a number.'
      };
      break;

    case 'float':
      var regex = /^[0-9]*.[0-9]*$/;
      var isValid = regex.test(value.trim());
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must be a float.'
      };
      break;

    case 'email':
      var isValid = emailRegex.test(value);
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must be an email address.'
      };
      break;

    case 'multipleEmail':
      var emailSplit = value.split(';');
      var isValid = true;

      for (var i = 0; i < emailSplit.length; i++) {
        var email = emailSplit[i].trim();

        if (email !== '') {
          isValid = emailRegex.test(email);

          if (!isValid) {
            return {
              valid: false,
              errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must be at least 1 email address'
            };
          }
        }
      }

      break;

    case 'webURL':
      var regex = /^(http(s?):\/\/)?[a-zA-Z0-9\.\-\_]+(\.[a-zA-Z]{2,3})+(\/[a-zA-Z0-9\_\-\s\.\/\?\%\#\&\=]*)?$/i;
      var isValid = regex.test(value.trim());
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must be a web address.'
      };

    case 'isInArray':
      var isValid = array ? array.indexOf(value) > -1 : true;
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must exist in the array supplied.'
      };
      break;

    case 'isInArrayIgnoreCase':
      var isValid = false;

      for (var i = 0; i < array.length; i++) {
        if (!isValid && array[i].toLowerCase().trim() == value.toLowerCase().trim()) {
          value = array[i];
          isValid = true;
          break;
        }
      }

      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value must exist in the array supplied.'
      };
      break;

    case 'isNotInArray':
      var isValid = array ? array.indexOf(value) === -1 : true;
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value already exists in the array supplied.'
      };
      break;

    case 'isNotInArrayIgnoreCase':
      var isValid = true;

      for (var i = 0; i < array.length; i++) {
        if (isValid && array[i].toLowerCase().trim() == value.toLowerCase().trim()) {
          value = array[i];
          isValid = false;
          break;
        }
      }

      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value already exists in the array supplied.'
      };
      break;

    case 'price':
      var regex = /^\d*(\.\d{1,2})?$/;
      var isValid = regex.test(value);
      if (!isValid) return {
        valid: false,
        errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Control value is not a price.'
      };
      break;

    default:
      return {
        valid: false,
        errorMsg: "Validation action not recognised. Please choose from a preset validation method name, supply your own validation function or supply a regular expression."
      };
  }

  return {
    valid: true
  };
};

var customFunction = function customFunction(value, customFnc, errorMsg) {
  var isValid = customFnc(value);

  if (isValid === false) {
    return {
      valid: false,
      errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Custom function validation failed.'
    };
  } else if (isValid === true) {
    return {
      valid: true
    };
  } else {
    return {
      valid: false,
      errorMsg: "Return value of a custom validation function must return true or false."
    };
  }
};

var regexValidation = function regexValidation(value, regex, errorMsg) {
  var isValid = regex.test(value);
  if (!isValid) return {
    valid: false,
    errorMsg: errorMsgStringBuilder(errorMsg, value) || 'Regex validation failed.'
  };
  return {
    valid: true
  };
};

var errorMsgStringBuilder = function errorMsgStringBuilder(errorMsg, value) {
  return errorMsg ? errorMsg.replace('{0}', value) : null;
};

var _default = Validation;
exports["default"] = _default;